==> zio-aws-devicefarm_3-5.17.112.1-sources.jar: zio/aws/devicefarm/model/GetAccountSettingsResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetAccountSettingsResponse(
    accountSettings: Option[zio.aws.devicefarm.model.AccountSettings] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse = {
    import GetAccountSettingsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse
      .builder()
      .optionallyWith(accountSettings.map(value => value.buildAwsValue()))(
        _.accountSettings
      )
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.GetAccountSettingsResponse.ReadOnly =
    zio.aws.devicefarm.model.GetAccountSettingsResponse.wrap(buildAwsValue())
}
object GetAccountSettingsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.GetAccountSettingsResponse =
      zio.aws.devicefarm.model.GetAccountSettingsResponse(
        accountSettings.map(value => value.asEditable)
      )
    def accountSettings
        : Option[zio.aws.devicefarm.model.AccountSettings.ReadOnly]
    def getAccountSettings: ZIO[
      Any,
      AwsError,
      zio.aws.devicefarm.model.AccountSettings.ReadOnly
    ] = AwsError.unwrapOptionField("accountSettings", accountSettings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse
  ) extends zio.aws.devicefarm.model.GetAccountSettingsResponse.ReadOnly {
    override val accountSettings
        : Option[zio.aws.devicefarm.model.AccountSettings.ReadOnly] = scala
      .Option(impl.accountSettings())
      .map(value => zio.aws.devicefarm.model.AccountSettings.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse
  ): zio.aws.devicefarm.model.GetAccountSettingsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-devicefarm_3-6.20.74.2-sources.jar: zio/aws/devicefarm/model/GetAccountSettingsResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetAccountSettingsResponse(
    accountSettings: Optional[zio.aws.devicefarm.model.AccountSettings] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse = {
    import GetAccountSettingsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse
      .builder()
      .optionallyWith(accountSettings.map(value => value.buildAwsValue()))(
        _.accountSettings
      )
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.GetAccountSettingsResponse.ReadOnly =
    zio.aws.devicefarm.model.GetAccountSettingsResponse.wrap(buildAwsValue())
}
object GetAccountSettingsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.GetAccountSettingsResponse =
      zio.aws.devicefarm.model.GetAccountSettingsResponse(
        accountSettings.map(value => value.asEditable)
      )
    def accountSettings
        : Optional[zio.aws.devicefarm.model.AccountSettings.ReadOnly]
    def getAccountSettings: ZIO[
      Any,
      AwsError,
      zio.aws.devicefarm.model.AccountSettings.ReadOnly
    ] = AwsError.unwrapOptionField("accountSettings", accountSettings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse
  ) extends zio.aws.devicefarm.model.GetAccountSettingsResponse.ReadOnly {
    override val accountSettings
        : Optional[zio.aws.devicefarm.model.AccountSettings.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.accountSettings())
        .map(value => zio.aws.devicefarm.model.AccountSettings.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.GetAccountSettingsResponse
  ): zio.aws.devicefarm.model.GetAccountSettingsResponse.ReadOnly = new Wrapper(
    impl
  )
}
